@@ -23,7 +23,7 @@ sub _is_fork_safe {
     return 1;
 }
 
-__PACKAGE__->mk_accessors(qw( dsn username password connect_options dbh get_dbh dbd prefix reuse_dbh force_no_prepared_cache));
+__PACKAGE__->mk_accessors(qw( dsn username password connect_options get_dbh dbd prefix reuse_dbh force_no_prepared_cache));
 
 
 sub init {
@@ -52,7 +52,7 @@ sub init {
         weaken(my $driver_weaken = $driver);
         POSIX::AtFork->add_to_child(sub {
             return unless $driver_weaken;
-            $driver_weaken->dbh(undef);
+            $driver_weaken->{dbh} = undef;
             %Handles = ();
         });
     }
@@ -108,6 +108,18 @@ sub init_db {
     return $dbh;
 }
 
+sub dbh {
+    my $driver = shift;
+    if (@_) {
+        my $dbh = $driver->{dbh} = shift;
+        if (!$dbh && $driver->reuse_dbh) {
+            $dbh = delete $Handles{$driver->dsn};
+            $dbh->disconnect if $dbh;
+        }
+    }
+    $driver->{dbh};
+}
+
 sub rw_handle {
     my $driver = shift;
     my $db = shift || 'main';
